@@ -1,7 +1,7 @@
 package Text::ANSITable;
 
-our $DATE = '2016-03-09'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $DATE = '2016-03-11'; # DATE
+our $VERSION = '0.48'; # VERSION
 
 use 5.010001;
 use Carp;
@@ -270,17 +270,17 @@ sub BUILD {
     unless (defined $self->{wide}) {
         $self->{wide} = eval { require Text::ANSI::WideUtil; 1 } ? 1:0;
     }
-    require Text::ANSI::NonWideUtil;
-    $self->{_func_add_color_resets} = \&Text::ANSI::NonWideUtil::ta_add_color_resets;
+    require Text::ANSI::Util;
+    $self->{_func_add_color_resets} = \&Text::ANSI::Util::ta_add_color_resets;
     if ($self->{wide}) {
         require Text::ANSI::WideUtil;
         $self->{_func_length_height} = \&Text::ANSI::WideUtil::ta_mbswidth_height;
         $self->{_func_pad}           = \&Text::ANSI::WideUtil::ta_mbpad;
         $self->{_func_wrap}          = \&Text::ANSI::WideUtil::ta_mbwrap;
     } else {
-        $self->{_func_length_height} = \&Text::ANSI::NonWideUtil::ta_length_height;
-        $self->{_func_pad}           = \&Text::ANSI::NonWideUtil::ta_pad;
-        $self->{_func_wrap}          = \&Text::ANSI::NonWideUtil::ta_wrap;
+        $self->{_func_length_height} = \&Text::ANSI::Util::ta_length_height;
+        $self->{_func_pad}           = \&Text::ANSI::Util::ta_pad;
+        $self->{_func_wrap}          = \&Text::ANSI::Util::ta_wrap;
     }
 }
 
@@ -1671,7 +1671,7 @@ Text::ANSITable - Create nice formatted tables using extended ASCII and ANSI col
 
 =head1 VERSION
 
-This document describes version 0.47 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2016-03-09.
+This document describes version 0.48 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2016-03-11.
 
 =head1 SYNOPSIS
 
@@ -2880,7 +2880,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Text-ANSIT
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Text-ANSITable>.
+Source repository is at L<https://github.com/perlancar/perl-Text-ANSITable>.
 
 =head1 BUGS
 
